==> skill-core-17.0.9-sources.jar: com/ptteng/sca/common/skill/client/TemplateTestSCAClient.java <==
package com.ptteng.sca.common.skill.client;

import com.ptteng.common.skill.model.InDoorStudentStatistics;
import com.ptteng.common.skill.service.TemplateTestService;

import java.util.List;

/**
 * Created by J.w on 2018/3/23.
 * 功能描述：
 */
public class TemplateTestSCAClient implements TemplateTestService{

    private TemplateTestService templateTestService;

    public TemplateTestService getTemplateTestService() {
        return templateTestService;
    }


    public void setTemplateTestService(TemplateTestService templateTestService) {
        this.templateTestService =templateTestService;
    }

    @Override
    public void updateIsLookNumber() {
        templateTestService.updateIsLookNumber();
    }

    @Override
    public List<InDoorStudentStatistics> getLineChartByParams(String school, String place, String major, Integer grade, Integer occupationId, Integer age, Long minStartAt, Long maxStartAt) {
        return templateTestService.getLineChartByParams(school, place, major, grade, occupationId, age, minStartAt, maxStartAt);
    }

    @Override
    public List<InDoorStudentStatistics> getPieCharByParams(Long minPassAt, Long maxPassAt, Integer occupationId, Integer condition) {
        return templateTestService.getPieCharByParams(minPassAt, maxPassAt, occupationId, condition);
    }

    @Override
    public Integer getRecordTotalNumber(Integer status) {
        return templateTestService.getRecordTotalNumber(status);
    }

    @Override
    public Long getProvinceIdByProvince(String province) {
        return templateTestService.getProvinceIdByProvince(province);
    }

    @Override
    public Long getCityIdByCity(String city) {
        return templateTestService.getCityIdByCity(city);
    }

    @Override
    public Long getCountyIdByCounty(String county) {
        return templateTestService.getCountyIdByCounty(county);
    }

}

==> skill-core-18.0.1-sources.jar: com/ptteng/sca/common/skill/client/TemplateTestSCAClient.java <==
package com.ptteng.sca.common.skill.client;

import com.ptteng.common.skill.model.InDoorStudentStatistics;
import com.ptteng.common.skill.service.TemplateTestService;

import java.util.List;

/**
 * Created by J.w on 2018/3/23.
 * 功能描述：
 */
public class TemplateTestSCAClient implements TemplateTestService{

    private TemplateTestService templateTestService;

    public TemplateTestService getTemplateTestService() {
        return templateTestService;
    }


    public void setTemplateTestService(TemplateTestService templateTestService) {
        this.templateTestService =templateTestService;
    }

    @Override
    public void updateIsLookNumber() {
        templateTestService.updateIsLookNumber();
    }

    @Override
    public List<InDoorStudentStatistics> getLineChartByParams(String school, String place, String major, Integer grade, Integer occupationId, Integer age, Long minStartAt, Long maxStartAt) {
        return templateTestService.getLineChartByParams(school, place, major, grade, occupationId, age, minStartAt, maxStartAt);
    }

    @Override
    public List<InDoorStudentStatistics> getPieCharByParams(Long minPassAt, Long maxPassAt, Integer occupationId, Integer condition) {
        return templateTestService.getPieCharByParams(minPassAt, maxPassAt, occupationId, condition);
    }

    @Override
    public Integer getRecordTotalNumber(Integer status) {
        return templateTestService.getRecordTotalNumber(status);
    }

    @Override
    public Long getProvinceIdByProvince(String province) {
        return templateTestService.getProvinceIdByProvince(province);
    }

    @Override
    public Long getCityIdByCity(String city) {
        return templateTestService.getCityIdByCity(city);
    }

    @Override
    public Long getCountyIdByCounty(String county, Long cityId) {
        return templateTestService.getCountyIdByCounty(county, cityId);
    }

}
